oci
    * ``auth_config_file`` The full path including filename to an oci configuration file.

    * ``auth_profile`` The name of the profile to use (case-sensitive).

    * ``auth_user`` The ocid of the user calling the api.

    * ``auth_tenancy`` The ocid of your tenancy.

    * ``auth_fingerprint`` The fingerprint for the public key that was added to the calling user.

    * ``auth_key_content`` The full content of the calling user's private signing key in pem format.

    * ``auth_key_file`` The full path including filename to the calling user's private signing key in pem format.

    * ``auth_pass_phrase`` If the private key is encrypted, the pass phrase must be provided.

    * ``auth_region`` An oci region identifier. select the closest region for best performance.

    * ``auth_type`` Valid options are 'api_key' (default) or 'instance_principal'.


.. note::
   
   Oracle Cloud Infrastructure (OCI) DNS provider
   

